==> haskell-x509-validation-1.6.11-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.11
id: x509-validation-1.6.11-IOVErwhCi2a5uJdrXI0LyO
key: x509-validation-1.6.11-IOVErwhCi2a5uJdrXI0LyO
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation. please see README
category: Data
abi: eae01ab7ff27efa850e576a6b06b599e
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
import-dirs: /usr/lib/ghc-8.6.4/site-local/x509-validation-1.6.11
library-dirs: /usr/lib/ghc-8.6.4/site-local/x509-validation-1.6.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/x509-validation-1.6.11
hs-libraries: HSx509-validation-1.6.11-IOVErwhCi2a5uJdrXI0LyO
depends:
    asn1-encoding-0.9.5-1HooVrxELdT8EXBBjBMSfy
    asn1-types-0.3.2-2K0ANkYzFxWBu24WOGrxw8 base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hourglass-0.2.12-4Si5cuysh1XI8xL9F9SZUc
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6 mtl-2.2.2
    pem-0.2.4-6Iq0FAdwpD6EIKncbzv7we x509-1.7.5-AGDNqwGGf1H926kJ4arIa9
    x509-store-1.6.7-88pb0Kevlb9IcsIUnLZPRY
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-validation-1.6.11-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.11
id: x509-validation-1.6.11-36YkUpy4q60CofQpkCcSEP
key: x509-validation-1.6.11-36YkUpy4q60CofQpkCcSEP
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation. please see README
category: Data
abi: 3255462be2d4c23f9d6d5d44f7c3b294
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
import-dirs: /usr/lib/ghc-8.6.4/site-local/x509-validation-1.6.11
library-dirs: /usr/lib/ghc-8.6.4/site-local/x509-validation-1.6.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/x509-validation-1.6.11
hs-libraries: HSx509-validation-1.6.11-36YkUpy4q60CofQpkCcSEP
depends:
    asn1-encoding-0.9.5-KIcWSI2LcvrF1kf3kfNm3M
    asn1-types-0.3.2-8Z3apqLMwrKLZ3FS4lTWYk base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hourglass-0.2.12-KsW9fNpReKB4iNOqgeVwjW
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6 mtl-2.2.2
    pem-0.2.4-6Iq0FAdwpD6EIKncbzv7we x509-1.7.5-4UJhh5NPMuwB64nGGQQFaV
    x509-store-1.6.7-7LPaDQEBpr0B4joV4k4DuJ
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
